.. _authors_ref:

Authors
-----------------------------------


The following is a list of authors who have made substantial contributions to
the conception or design of this software; or the creation of new code used in
this software; or have drafted the work or substantively revised it and are
considered "The PyProcar Developers":

- Aldo Romero
- Francisco Muñoz,
- Logan Lang,
- Sobhit Singh,
- Uthpala Herath,
- Pedram Tavadze,
- Eric Bousquet,
- Xu He,
- Reese Boucher,
- Freddy Farah,


Contributors
-----------------------------------


Throughout the years, PyProcar has transformed into a global community effort. The PyProcar development team thanks the contributions from:

- `Jan Janssen <https://github.com/jan-janssen>`_
- `Litong Jiang <https://github.com/lovelitong2046>`_
- `Nicholas Pike <https://github.com/Npikeulg>`_

Please contact us if you don't see your name on the list. 


Developers
-----------------------------------

1. Francisco Munoz [a]
2. Aldo Romero [b]
3. Uthpala Herath [b]
4. Pedram Tavadze [b]
5. Sobhit Singh [c]
6. Eric Bousquet [d]
7. Xu He [d]
8. Reese Boucher [b]
9. Logan Lang [b]

[a] Departamento de F\'isica, Facultad de Ciencias, Universidad de Chile, Santiago, Chile; Center for the Development of Nanoscience and Nanotechnology (CEDENNA), Santiago, Chile

[b] Department of Physics and Astronomy, West Virginia University, Morgantown, WV 26505-6315, USA

[c] Department of Physics and Astronomy, Rutgers University, Piscataway, NJ 08854, USA

[d] Physique Th\'eorique des Mat\'eriaux, CESAM, Universit\'e de Li\`ege, B-4000 Sart-Tilman, Belgium